<?php
namespace App\Controllers;

class AppBuilder extends BaseController
{
    public function index()
    {
        $modulesDir = APPPATH . 'Modules/';
        $moduleFiles = glob($modulesDir . '*.php');
        $moduleMarkup = [];
        $modules = [];

        foreach ($moduleFiles as $file) {
            require_once $file;
            $moduleName = basename($file, '.php');
            if (class_exists($moduleName)) {
                $moduleInstance = new $moduleName();
                $moduleMarkup[$moduleName] = $moduleInstance->render();
                $modules[] = [
                    'name' => $moduleName,
                    'buttonName' => $moduleInstance->settings['buttonName'] ?? $moduleName,
                    'position' => $moduleInstance->settings['buttonPosition'] ?? 999,
                ];
            }
        }

        usort($modules, fn($a, $b) => $a['position'] <=> $b['position']);

        return view('app_builder_ui', [
            'modules' => $modules,
            'moduleMarkup' => $moduleMarkup
        ]);
    }

    public function saveApp()
    {
        $request = $this->request->getJSON();
        log_message('debug', 'saveApp Request: ' . print_r($request, true));

        $appName = trim($request->appName);
        $appSlug = trim($request->appSlug);
        $modules = $request->modules;

        if (empty($appName) || empty($appSlug)) {
            return $this->response->setJSON(["success" => false, "message" => "Application name and URL slug are required."]);
        }

        $appModel = new \App\Models\AppModel();

        if ($appModel->where('slug', $appSlug)->first()) {
            return $this->response->setJSON(["success" => false, "message" => "This URL slug is already taken."]);
        }

        $data = [
            'name' => $appName,
            'slug' => $appSlug,
            'modules' => json_encode($modules),
            'created_at' => date("Y-m-d H:i:s")
        ];

        $insertID = $appModel->insert($data);

        if (!$insertID) {
            log_message('error', 'Failed to insert app data: ' . print_r($appModel->errors(), true));
            return $this->response->setJSON(["success" => false, "message" => "Failed to save application data."]);
        }

        return $this->response->setJSON(["success" => true, "insertID" => $insertID]);
    }

    public function loadApp($appSlug)
    {
        $appModel = new \App\Models\AppModel();
        $appData = $appModel->where('slug', $appSlug)->first();

        if (!$appData) {
            return $this->response->setJSON(["success" => false, "message" => "Application not found."]);
        }

        $appData['modules'] = json_decode($appData['modules'], true);
        return view('loaded_app', ["appData" => $appData]);
    }

    public function testInsert()
    {
        $appModel = new \App\Models\AppModel();
        $data = [
            'name' => 'Complex Test App',
            'slug' => 'complex-test-app',
            'modules' => json_encode([]),
            'created_at' => date("Y-m-d H:i:s")
        ];
        $insertID = $appModel->insert($data);
        echo $insertID ? "Inserted record ID: " . $insertID : "Insertion failed: " . print_r($appModel->errors(), true);
    }
}
