<?php
ini_set('display_errors', 1);
error_reporting(E_ALL);

// Helper function
if (!function_exists('esc')) {
    function esc($string) {
        return htmlspecialchars($string, ENT_QUOTES, 'UTF-8');
    }
}

class PageBreak {
    private $settings;
    private $instanceId;

    public function __construct($instanceId = '', $settings = []) {
        $this->instanceId = $instanceId ?: uniqid('pageBreak_');
        $this->settings = array_merge([
            'pageName'      => 'Untitled',    // Default page name
            'buttonName'    => 'Page Break',  // Sidebar button label
            'buttonPosition'=> 10,
            'leftLogo'      => 'https://main.winslowapps.com/app-creator/logo-placeholder-image.png',
            'rightLogo'     => 'https://main.winslowapps.com/app-creator/logo-placeholder-image.png'
        ], $settings);
    }

    // Renders the module preview inside the canvas
    public function render() {
        ob_start(); ?>
        <div class="module-preview page-break-module" 
             data-module="PageBreak" 
             data-module-id="<?php echo esc($this->instanceId); ?>"
             data-page-name="<?php echo esc($this->settings['pageName']); ?>">

            <!-- Footer Section with Logos and Button -->
            <div class="bottom-section" style="
                position: relative;
                width: 100%;
                text-align: center;
                padding: 10px 20px;
                box-sizing: border-box;
            ">
                <div class="bottom-logos" style="position: relative;">

                    <!-- Left Logo -->
                    <div class="logo-container left-logo" style="
                        position: absolute;
                        bottom: 0;
                        left: 5%;
                        width: 10%;
                        transform: translateY(50%);
                    ">
                        <img src="<?php echo esc($this->settings['leftLogo']); ?>" alt="Left Logo" style="width: 100%; height: auto;">
                    </div>

                    <!-- Navigation Button -->
                    <button class="bottom-button" 
                            style="position: relative; padding: 10px 20px; background: #2c3e8f; color: #fff; border: none; border-radius: 4px; font-size: 1em; cursor: pointer; min-width: 80px;"
                            data-page-btn 
                            data-page-index="">
                        <span style="white-space: pre;"><?php echo esc($this->settings['buttonName']); ?></span>
                    </button>

                    <!-- Right Logo -->
                    <div class="logo-container right-logo" style="
                        position: absolute;
                        bottom: 0;
                        right: 5%;
                        width: 10%;
                        transform: translateY(50%);
                    ">
                        <img src="<?php echo esc($this->settings['rightLogo']); ?>" alt="Right Logo" style="width: 100%; height: auto;">
                    </div>
                </div>
            </div>

            <!-- Page Info Text -->
            <div class="page-info" style="text-align: center; margin-top: 10px; color: #555;">
                Page Name: <?php echo esc($this->settings['pageName']); ?>
            </div>

        </div>
        <?php
        return ob_get_clean();
    }

    // Sidebar button
    public function renderPreview() {
        return '<button class="module-selector-btn" data-module="PageBreak">' 
             . esc($this->settings['buttonName']) . 
             '</button>';
    }

    // Settings panel for Page Name
    public function renderSettings() {
        ob_start(); ?>
        <div class="form-group">
            <label for="pageName_<?php echo esc($this->instanceId); ?>">Page Name:</label>
            <input 
                type="text" 
                id="pageName_<?php echo esc($this->instanceId); ?>" 
                class="page-name-input" 
                value="<?php echo esc($this->settings['pageName']); ?>"
                data-target-module-id="<?php echo esc($this->instanceId); ?>"
            >
        </div>
        <?php
        return ob_get_clean();
    }
}
?>
