<?php
// modules/PageText.php

ini_set('display_errors', 1);
error_reporting(E_ALL);

if (!function_exists('esc')) {
    function esc($string) {
        return htmlspecialchars($string, ENT_QUOTES, 'UTF-8');
    }
}

class PageText {
    public $settings;
    private $instanceId;

    public function __construct($instanceId = '', $settings = []) {
        $this->instanceId = $instanceId ?: uniqid('pageText_');
        $this->settings = array_merge([
            'buttonName'    => 'Page Text',  // ✅ Button name for sidebar
            'content' => 'Many of us carry emotional burdens from tragic or painful life experiences. At times, we have been abused or forsaken by the very people we loved. This can produce deep levels of distrust and relational barriers toward others, even the ones that the Lord sends into our lives.<br><br>
According to the verses shown above, there’s an important step we must take before we can fully accept new friends, or repair former, estranged relationships. We first need to identify the original perpetrators of our relational pain and then “liberate” them from the emotional prison deep in our heart. This is why Jesus encouraged His followers to be merciful toward those who had trespassed against them. This is such an important issue that He also warned us not to resist this teaching. He concluded with a stark, strong warning by saying: “But if you don’t forgive others, neither will your Father in Heaven forgive your offenses.” (Matthew 6:15)<br><br>Does any of this sound familiar?',
            'fontSize'      => '20px',
            'fontWeight'    => 'bold',
            'textAlign'     => 'left',
            'textBoxAlign'  => 'flex-start',
            'width'         => '60%',
            'paddingTop'    => '10px',
            'paddingRight'  => '10px',
            'paddingBottom' => '10px',
            'paddingLeft'   => '10px',
            'marginTop'     => '10px',
            'marginRight'   => 'auto',
            'marginBottom'  => '10px',
            'marginLeft'    => 'auto',
        ], $settings);
    }

    // ✅ Renders the module into the canvas
    public function render() {
        ob_start(); ?>
        
        <div class="module-preview page-text-module"
             data-module="PageText"
             data-module-id="<?php echo esc($this->instanceId); ?>"
             style="display: flex; justify-content: <?php echo esc($this->settings['textBoxAlign']); ?>;">
             
            <div class="text-container"
                 style="width: <?php echo esc($this->settings['width']); ?>;
                        text-align: <?php echo esc($this->settings['textAlign']); ?>;
                        font-size: <?php echo esc($this->settings['fontSize']); ?>;
                        font-weight: <?php echo esc($this->settings['fontWeight']); ?>;
                        font-family: 'Open Sans', sans-serif;
                        padding: <?php echo esc($this->settings['paddingTop']) . ' ' . esc($this->settings['paddingRight']) . ' ' . esc($this->settings['paddingBottom']) . ' ' . esc($this->settings['paddingLeft']); ?>;
                        margin: <?php echo esc($this->settings['marginTop']) . ' ' . esc($this->settings['marginRight']) . ' ' . esc($this->settings['marginBottom']) . ' ' . esc($this->settings['marginLeft']); ?>;">
                
                <p style="white-space: normal;">
                    <?php echo $this->settings['content']; ?>
                </p>
            </div>
        </div>
        
        <?php
        return ob_get_clean();
    }


// ✅ Sidebar button renders properly with buttonName
public function renderPreview() {
    return '<button class="module-selector-btn" data-module="PageText">' 
         . esc($this->settings['buttonName']) . 
         '</button>';
}

// ✅ Updated renderSettings() with TinyMCE modal trigger
public function renderSettings() {
    ob_start(); ?>
    
    <div class="form-group">
        <label>Text Content (click to edit):</label>
        <textarea id="pageTextEditor" readonly style="width: 100%; min-height: 120px; cursor: pointer;" data-update="content"><?php echo trim($this->settings['content']); ?></textarea>
        <small>Click inside this box to open the editor.</small>
    </div>
    
    <script>
    (function() {
        var editorTrigger = document.getElementById('pageTextEditor');
        if (editorTrigger) {
            // Ensure the textarea is read-only so users use the modal
            editorTrigger.readOnly = true;
            editorTrigger.addEventListener('click', function(e) {
                e.stopPropagation();
                console.log("Settings panel textarea clicked. Opening TinyMCE modal...");
                openTinyMCEModal(editorTrigger.value, function(updatedContent) {
                    console.log("Modal returned updated content:", updatedContent);
                    // Update the settings panel textarea
                    editorTrigger.value = updatedContent;
                    // Update the live module preview if a module is selected
                    var selectedModule = document.querySelector('.module-preview.selected');
                    if (selectedModule) {
                        var textElement = selectedModule.querySelector('.text-container p');
                        if (textElement) {
                            textElement.innerHTML = updatedContent;
                            console.log("Module preview updated with new content.");
                        } else {
                            console.warn("No text element found in the selected module.");
                        }
                    } else {
                        console.warn("No module is selected; cannot update preview.");
                    }
                });
            });
        } else {
            console.warn("Settings panel content textarea not found.");
        }
    })();
    </script>
    
    <?php
    return ob_get_clean();
}


}
?>
