<?php

namespace App\Controllers;

use CodeIgniter\Controller;

class WSAppMaker extends Controller
{
    public function index()
    {
        return view('ws_app_maker/index'); // This must match the folder + filename in Views
    }

    public function update_module()
    {
        $json = $this->request->getJSON(true);
        $instanceId = $json['instanceId'];
        $moduleName = $json['moduleName'];
        $settings = $json['settings'];
    
        $moduleFile = APPPATH . "Modules/{$moduleName}.php";
    
        if (!file_exists($moduleFile)) {
            return $this->response->setJSON(['error' => 'Module not found.']);
        }
    
        require_once $moduleFile;
        $module = new $moduleName();
    
        $preview = $module->renderPreview($settings);
        $settingsPanel = $module->renderSettings($settings);
    
        return $this->response->setJSON([
            'preview' => $preview,
            'settings' => $settingsPanel
        ]);
    }

    // ✅ NEW: Save a full app and its modules
    public function save_app()
    {
        $request = service('request');
        $data = $request->getJSON(true);

        $db = \Config\Database::connect();
        $builder = $db->table('apps');

        $db->transStart();

        $appData = [
            'name' => $data['name'],
            'slug' => url_title($data['name'], '-', true),
            'created_at' => date('Y-m-d H:i:s'),
            'updated_at' => date('Y-m-d H:i:s'),
        ];
        $builder->insert($appData);
        $appId = $db->insertID();

        $modBuilder = $db->table('app_modules');
        foreach ($data['modules'] as $index => $module) {
            $modBuilder->insert([
                'app_id' => $appId,
                'module' => $module['name'],
                'settings' => json_encode($module['settings']),
                'order' => $index,
                'created_at' => date('Y-m-d H:i:s'),
                'updated_at' => date('Y-m-d H:i:s'),
            ]);
        }

        $db->transComplete();

        return $this->response->setJSON([
            'status' => 'success',
            'app_id' => $appId
        ]);
    }

    // ✅ NEW: Load app and its modules by ID
    public function load_app($id)
    {
        $db = \Config\Database::connect();

        $app = $db->table('apps')->where('id', $id)->get()->getRowArray();
        $modules = $db->table('app_modules')
            ->where('app_id', $id)
            ->orderBy('order', 'ASC')
            ->get()
            ->getResultArray();

        return $this->response->setJSON([
            'status' => 'success',
            'app' => $app,
            'modules' => $modules
        ]);
    }

    // ✅ NEW: List all saved apps
    public function list_apps()
    {
        $apps = \Config\Database::connect()->table('apps')
            ->orderBy('created_at', 'DESC')
            ->get()
            ->getResultArray();

        return $this->response->setJSON($apps);
    }
}
