<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>App Builder Interface</title>
    <style>
        body { font-family: Arial, sans-serif; padding: 20px; }
        .module-btn { margin: 5px; padding: 10px 15px; background-color: #3498db; color: #fff; border: none; cursor: pointer; }
        .module-btn:hover { background-color: #2980b9; }
        #builder-area { border: 1px solid #ccc; padding: 20px; min-height: 300px; background: #f9f9f9; margin-top: 20px; }
    </style>
</head>
<body>

<h1>🚀 App Builder</h1>

<!-- Module Buttons -->
<div>
<?php
// Auto-load and render module buttons dynamically
$modulesDir = APPPATH . 'Modules/AppMaker/modules/';
$moduleFiles = glob($modulesDir . '*.php');
$modules = [];

foreach ($moduleFiles as $file) {
    require_once $file;
    $moduleName = basename($file, '.php');
    if (class_exists($moduleName)) {
        $moduleInstance = new $moduleName();
        $modules[] = [
            'name' => $moduleName,
            'buttonName' => $moduleInstance->settings['buttonName'] ?? $moduleName,
            'position' => $moduleInstance->settings['buttonPosition'] ?? 999,
            'html' => $moduleInstance->render(),
        ];
    }
}

// Sort modules by button position
usort($modules, fn($a, $b) => $a['position'] <=> $b['position']);

// Render module buttons
foreach ($modules as $module) {
    echo '<button class="module-btn" onclick="addModule(`' . esc($module['html']) . '`)">' . esc($module['buttonName']) . '</button>';
}
?>
</div>

<!-- App Builder Canvas -->
<form method="POST" action="<?= site_url('save_app') ?>">
    <input type="text" name="app_name" placeholder="App Name" required><br><br>
    <div id="builder-area" contenteditable="true">
        <!-- User builds here -->
    </div>
    <input type="hidden" name="app_content" id="app_content">
    <br><button type="submit">💾 Save App</button>
</form>

<script>
function addModule(html) {
    const area = document.getElementById('builder-area');
    area.innerHTML += html;
}

// Before submitting, grab the content
document.querySelector('form').addEventListener('submit', function(e) {
    document.getElementById('app_content').value = document.getElementById('builder-area').innerHTML;
});
</script>

</body>
</html>
