document.addEventListener('DOMContentLoaded', function () {
    const settingsPanel = document.getElementById('settings-pane');
    const canvas = document.getElementById('canvas');

    /** ✅ Load Module Settings When a Module is Clicked */
    window.loadModuleSettings = function (module, moduleType) {
        settingsPanel.innerHTML = ''; // Clear previous settings

        // ✅ Prevent errors if module settings don't exist
        const settingsHTML = moduleSettingsMarkup[moduleType] || null;

        if (settingsHTML) {
            settingsPanel.innerHTML = `
                <h2>Module Settings</h2>
                ${settingsHTML}
            `;

            const textContainer = module.querySelector('.text-container');
            if (!textContainer) return;

            // ✅ Auto-detect inputs and apply updates dynamically
            settingsPanel.querySelectorAll('[data-update]').forEach(input => {
                const settingName = input.getAttribute('data-update');

                if (settingName === "content") {
                    if (typeof tinymce !== "undefined") {
                        tinymce.get('textContent')?.setContent(textContainer.querySelector('p').innerHTML);
                    } else {
                        input.value = textContainer.querySelector('p').innerHTML;
                    }
                } else {
                    input.value = textContainer.style[settingName] || "";
                }

                input.addEventListener('input', function () {
                    applySettingToModule(module, settingName, this.value);
                });
            });

            // ✅ Initialize TinyMCE editor dynamically AFTER it's fully loaded
            setTimeout(() => {
                if (document.getElementById('textContent')) {
                    tinymce.init({
                        selector: '#textContent',
                        menubar: false,
                        toolbar: 'bold italic underline | alignleft aligncenter alignright alignjustify | bullist numlist outdent indent',
                        license_key: 'gpl', // ✅ Fix License Issue
                        setup: function (editor) {
                            editor.on('input', function () {
                                module.querySelector('.text-container p').innerHTML = editor.getContent();
                            });
                        }
                    });
                }
            }, 500);
        } else {
            settingsPanel.innerHTML = '<h2>No settings defined for this module.</h2>';
        }
    };

    /** ✅ Apply Changes Dynamically to Selected Module */
    function applySettingToModule(module, setting, value) {
        const textContainer = module.querySelector('.text-container');
        if (!textContainer) return;

        if (setting === "content") {
            textContainer.querySelector('p').innerHTML = value;
        } else {
            textContainer.style[setting] = value;
        }
    }

    /** ✅ Detect Clicks on Modules & Load Settings */
    canvas.addEventListener('click', function (e) {
        const clickedModule = e.target.closest('.module-preview');
        if (clickedModule) {
            document.querySelectorAll('.module-preview').forEach(m => m.classList.remove('selected'));
            clickedModule.classList.add('selected');

            const moduleType = clickedModule.getAttribute('data-module');
            loadModuleSettings(clickedModule, moduleType);
        }
    });
});
