<?php
// modules/TitlePageModule.php

ini_set('display_errors', 1);
error_reporting(E_ALL);

// Helper functions if not already defined
if (!function_exists('base_url')) {
    function base_url($path = '') {
        return "https://main.winslowapps.com/" . ltrim($path, '/');
    }
}

if (!function_exists('esc')) {
    function esc($string) {
        return htmlspecialchars($string, ENT_QUOTES, 'UTF-8');
    }
}

class TitlePageModule {
    private $settings;
    private $instanceId;

    public function __construct($instanceId = '', $settings = []) {
        $this->instanceId = $instanceId ?: uniqid('titlePage_');
        // Default settings with placeholder images.
        $this->settings = array_merge([
            'title'         => 'Enter Title Here',
            'subtitle'      => 'Enter Subtitle Here',
            'author'        => 'By Author Name',
            'topLogo'       => base_url('logo-placeholder-image.png'),
            'topLogoWidth'  => 15,
            'leftLogo'      => base_url('logo-placeholder-image.png'),
            'leftLogoWidth' => 10,
            'rightLogo'     => base_url('logo-placeholder-image.png'),
            'rightLogoWidth'=> 10,
        ], $settings);
    }

    public function render() {
        ob_start();
        ?>
        <div class="title-page-container title-page-module" data-module="TitlePageModule" data-module-id="<?php echo esc($this->instanceId); ?>">
            <div class="title-content">
                
                <!-- Top Logo (centered near top) -->
                <div class="top-logo" style="
                    position: absolute;
                    top: 5%;
                    left: 50%;
                    transform: translateX(-50%);
                    width: <?php echo esc($this->settings['topLogoWidth']); ?>%;
                ">
                    <img src="<?php echo esc($this->settings['topLogo']); ?>" alt="Top Logo" style="width: 100%; height: auto;">
                </div>
                
                <!-- Title & Subtitle Section (centered in middle) -->
                <div class="title-section" style="
                    position: absolute;
                    top: 30%;
                    left: 50%;
                    transform: translateX(-50%);
                    width: 70%;
                    text-align: center;
                ">
                    <div class="title-line"></div>
                    <h1><?php echo esc($this->settings['title']); ?></h1>
                    <h2><?php echo esc($this->settings['subtitle']); ?></h2>
                    <div class="title-line"></div>
                    <h3><?php echo esc($this->settings['author']); ?></h3>
                </div>
                
                <!-- Bottom Section: Logos and Begin Button -->
                <div class="bottom-section" style="
                    position: absolute;
                    bottom: 20px;
                    left: 0;
                    right: 0;
                    text-align: center;
                    padding: 10px 20px;
                    box-sizing: border-box;
                ">
                    <div class="bottom-logos">
                        <div class="logo-container left-logo" style="
                            position: absolute;
                            bottom: 0;
                            left: 5%;
                            width: <?php echo esc($this->settings['leftLogoWidth']); ?>%;
                            transform: translateY(50%);
                        ">
                            <img src="<?php echo esc($this->settings['leftLogo']); ?>" alt="Left Logo" style="width: 100%; height: auto;">
                        </div>

                        <button class="bottom-button" style="
                            position: relative;
                            padding: 10px 20px;
                            background: #2c3e8f;
                            color: #fff;
                            border: none;
                            border-radius: 4px;
                            font-size: 1em;
                            cursor: pointer;
                            min-width: 80px;
                        ">
                            Begin
                        </button>

                        <div class="logo-container right-logo" style="
                            position: absolute;
                            bottom: 0;
                            right: 5%;
                            width: <?php echo esc($this->settings['rightLogoWidth']); ?>%;
                            transform: translateY(50%);
                        ">
                            <img src="<?php echo esc($this->settings['rightLogo']); ?>" alt="Right Logo" style="width: 100%; height: auto;">
                        </div>
                    </div>
                </div>

            </div>
        </div>
        <?php
        return ob_get_clean();
    }

    // Simple Preview for Dashboard
    public function renderPreview() {
        return '<div class="module-preview" data-module="TitlePageModule"><strong>Title Page:</strong> '.esc($this->settings['title']).'</div>';
    }
}
?>
