<?php
ini_set('display_errors', 1);
error_reporting(E_ALL);

if (!function_exists('esc')) {
    function esc($string) {
        return htmlspecialchars($string, ENT_QUOTES, 'UTF-8');
    }
}
?>
<!-- No output before DOCTYPE -->

<?php
class PageText {
    public $settings;
    private $instanceId;

    public function __construct($instanceId = '', $settings = []) {
        // Updated default settings:
        $this->instanceId = $instanceId ?: uniqid('pageText_');
        $this->settings = array_merge([
            'buttonName'    => 'Page Text',
            'buttonPosition'  => 5,
            'content'       => 'Many of us carry emotional burdens from tragic or painful life experiences. At times, we have been abused or forsaken by the very people we loved. This can produce deep levels of distrust and relational barriers toward others, even the ones that the Lord sends into our lives.<br><br>
According to the verses shown above, there’s an important step we must take before we can fully accept new friends, or repair former, estranged relationships. We first need to identify the original perpetrators of our relational pain and then “liberate” them from the emotional prison deep in our heart. This is why Jesus encouraged His followers to be merciful toward those who had trespassed against them. This is such an important issue that He also warned us not to resist this teaching. He concluded with a stark, strong warning by saying: “But if you don’t forgive others, neither will your Father in Heaven forgive your offenses.” (Matthew 6:15)<br><br>Does any of this sound familiar?',
            'fontSize'      => '20px',
            'fontWeight'    => 'bold',
            // Inner text remains left aligned.
            'textAlign'     => 'left',
            // Container is centered.
            'textBoxAlign'  => 'center',
            // Container width updated to 75%.
            'width'         => '75%',
            'paddingTop'    => '10px',
            'paddingRight'  => '10px',
            'paddingBottom' => '10px',
            'paddingLeft'   => '10px',
            'marginTop'     => '10px',
            'marginRight'   => 'auto',
            'marginBottom'  => '10px',
            'marginLeft'    => 'auto',
        ], $settings);
    }

    // Renders the module preview on the canvas.
    // For testing, this preview is marked with "selected".
    public function render() {
        ob_start(); ?>
        
        <div class="module-preview page-text-module selected"
             data-module="PageText"
             data-module-id="<?php echo esc($this->instanceId); ?>"
             style="display: flex; justify-content: <?php echo esc($this->settings['textBoxAlign']); ?>;
                    margin: <?php echo esc($this->settings['marginTop']) . ' ' . esc($this->settings['marginRight']) . ' ' . esc($this->settings['marginBottom']) . ' ' . esc($this->settings['marginLeft']); ?>;">
             
            <div class="text-container"
                 style="width: <?php echo esc($this->settings['width']); ?>;
                        text-align: <?php echo esc($this->settings['textAlign']); ?>;
                        font-size: <?php echo esc($this->settings['fontSize']); ?>;
                        font-weight: <?php echo esc($this->settings['fontWeight']); ?>;
                        font-family: 'Open Sans', sans-serif;
                        padding: <?php echo esc($this->settings['paddingTop']) . ' ' . esc($this->settings['paddingRight']) . ' ' . esc($this->settings['paddingBottom']) . ' ' . esc($this->settings['paddingLeft']); ?>;">
                <p style="white-space: normal;">
                    <?php echo $this->settings['content']; ?>
                </p>
            </div>
        </div>
        
        <?php
        return ob_get_clean();
    }

    // Renders the module's preview button for the sidebar.
    public function renderPreview() {
        return '<button class="module-selector-btn" data-module="PageText">'
             . esc($this->settings['buttonName'])
             . '</button>';
    }

    // Renders the settings for the module, including text editing and spacing controls.
    public function renderSettings() {
        // Prepare spacing values.
        $spacing = [
            'margin' => [
                'top'    => isset($this->settings['marginTop']) ? $this->settings['marginTop'] : '10',
                'right'  => isset($this->settings['marginRight']) ? $this->settings['marginRight'] : 'auto',
                'bottom' => isset($this->settings['marginBottom']) ? $this->settings['marginBottom'] : '10',
                'left'   => isset($this->settings['marginLeft']) ? $this->settings['marginLeft'] : 'auto',
            ],
            'padding' => [
                'top'    => isset($this->settings['paddingTop']) ? $this->settings['paddingTop'] : '10',
                'right'  => isset($this->settings['paddingRight']) ? $this->settings['paddingRight'] : '10',
                'bottom' => isset($this->settings['paddingBottom']) ? $this->settings['paddingBottom'] : '10',
                'left'   => isset($this->settings['paddingLeft']) ? $this->settings['paddingLeft'] : '10',
            ]
        ];
        
        ob_start(); ?>
        
        <!-- Text Content Settings -->
        <div class="form-group">
            <label>Text Content:</label>
            <textarea id="pageTextEditor" readonly style="width: 100%; min-height: 120px; cursor: pointer;" data-update="content" onclick="openEditor()">
<?php echo trim($this->settings['content']); ?>
            </textarea>
            <small>Click inside this box to open the editor, or use the button below to edit.</small>
            <button id="editPageText" type="button" style="margin-top: 10px;" onclick="openEditor()">Edit Text</button>
        </div>
        
        <!-- Spacing Settings Partial -->
        <!-- You can extract the following block into a separate PHP file and include it if desired -->
        <div class="spacing-settings">
          <h3>Spacing Settings</h3>
          
          <!-- Margin Settings -->
          <div class="spacing-section">
            <h4>Margin</h4>
            <div class="spacing-inputs">
              <div class="spacing-item">
                <label for="marginTop">Top</label>
                <input type="number" id="marginTop" value="<?= htmlspecialchars($spacing['margin']['top']); ?>" min="0">
              </div>
              <div class="spacing-item">
                <label for="marginRight">Right</label>
                <input type="text" id="marginRight" value="<?= htmlspecialchars($spacing['margin']['right']); ?>" placeholder="auto">
              </div>
              <div class="spacing-item">
                <label for="marginBottom">Bottom</label>
                <input type="number" id="marginBottom" value="<?= htmlspecialchars($spacing['margin']['bottom']); ?>" min="0">
              </div>
              <div class="spacing-item">
                <label for="marginLeft">Left</label>
                <input type="text" id="marginLeft" value="<?= htmlspecialchars($spacing['margin']['left']); ?>" placeholder="auto">
              </div>
            </div>
          </div>
          
          <!-- Padding Settings -->
          <div class="spacing-section">
            <h4>Padding</h4>
            <div class="spacing-inputs">
              <div class="spacing-item">
                <label for="paddingTop">Top</label>
                <input type="number" id="paddingTop" value="<?= htmlspecialchars($spacing['padding']['top']); ?>" min="0">
              </div>
              <div class="spacing-item">
                <label for="paddingRight">Right</label>
                <input type="number" id="paddingRight" value="<?= htmlspecialchars($spacing['padding']['right']); ?>" min="0">
              </div>
              <div class="spacing-item">
                <label for="paddingBottom">Bottom</label>
                <input type="number" id="paddingBottom" value="<?= htmlspecialchars($spacing['padding']['bottom']); ?>" min="0">
              </div>
              <div class="spacing-item">
                <label for="paddingLeft">Left</label>
                <input type="number" id="paddingLeft" value="<?= htmlspecialchars($spacing['padding']['left']); ?>" min="0">
              </div>
            </div>
          </div>
        </div>
        
        <style>
          .spacing-settings {
            font-family: 'Open Sans', sans-serif;
            padding: 20px;
            background: #f9f9f9;
            border: 1px solid #ddd;
            border-radius: 8px;
            max-width: 400px;
            margin: 20px auto;
          }
          .spacing-settings h3 {
            margin-top: 0;
            font-size: 1.5em;
            color: #2c3e8f;
            text-align: center;
          }
          .spacing-section {
            margin-bottom: 20px;
          }
          .spacing-section h4 {
            margin-bottom: 10px;
            font-size: 1.2em;
            color: #2c3e8f;
            border-bottom: 1px solid #ddd;
            padding-bottom: 5px;
          }
          .spacing-inputs {
            display: grid;
            grid-template-columns: 1fr 1fr;
            gap: 10px;
          }
          .spacing-item {
            display: flex;
            flex-direction: column;
          }
          .spacing-item label {
            font-size: 0.9em;
            margin-bottom: 3px;
            color: #555;
          }
          .spacing-item input {
            padding: 5px;
            border: 1px solid #ccc;
            border-radius: 4px;
            font-size: 0.9em;
          }
        </style>
        
        <script>
          // Live update function for spacing settings.
          function liveUpdateSpacing() {
            var settings = {
              margin: {
                top: document.getElementById('marginTop').value,
                right: document.getElementById('marginRight').value,
                bottom: document.getElementById('marginBottom').value,
                left: document.getElementById('marginLeft').value
              },
              padding: {
                top: document.getElementById('paddingTop').value,
                right: document.getElementById('paddingRight').value,
                bottom: document.getElementById('paddingBottom').value,
                left: document.getElementById('paddingLeft').value
              }
            };
            console.log("Live spacing settings:", settings);
            // Update the live preview of the module if selected.
            var selectedModule = document.querySelector('.module-preview.selected');
            if (selectedModule) {
              selectedModule.style.marginTop = settings.margin.top + "px";
              selectedModule.style.marginRight = settings.margin.right;
              selectedModule.style.marginBottom = settings.margin.bottom + "px";
              selectedModule.style.marginLeft = settings.margin.left;
              var container = selectedModule.querySelector('.text-container');
              if (container) {
                container.style.paddingTop = settings.padding.top + "px";
                container.style.paddingRight = settings.padding.right + "px";
                container.style.paddingBottom = settings.padding.bottom + "px";
                container.style.paddingLeft = settings.padding.left + "px";
                console.log("Live preview updated with new spacing settings.");
              } else {
                console.warn("No text container found in selected module.");
              }
            } else {
              console.warn("No module selected; live update spacing not applied.");
            }
          }
          document.addEventListener('DOMContentLoaded', function() {
            var inputs = document.querySelectorAll('.spacing-settings input');
            inputs.forEach(function(input) {
              input.addEventListener('input', liveUpdateSpacing);
            });
          });
        </script>
        
        <?php
        return ob_get_clean();
    }
}
?>
