<?php
class PageTitle {
    public $settings;
    private $instanceId;

    public function __construct($instanceId = '', $settings = []) {
        $this->instanceId = $instanceId ?: uniqid('pageTitle_');
        $this->settings = array_merge([
            'title' => 'Sample Page Title',
            'fontSize' => 3,
            'fontFamily' => "'Cinzel', serif",
            'textColor' => '#2c3e8f',
            'marginBottom' => 30,
            'buttonName' => 'Page Title',
            'buttonPosition' => 1
        ], $settings);
    }

    // ✅ Dynamic settings: fonts + single-line title text input
    public function settingsConfig() {
        return [
            'fonts',      // ✅ Triggers fonts.js
            'titleText'   // ✅ Triggers the JS to render a single-line input for the title
        ];
    }

    // ✅ Render the module including the correct data-settings-config
    public function render() {
        ob_start(); ?>
        
        <div class="module-preview page-title-module" 
             data-module="PageTitle" 
             data-module-id="<?php echo esc($this->instanceId); ?>"
             data-settings-config='<?php echo json_encode($this->settingsConfig()); ?>'
             data-font-family="<?php echo esc($this->settings['fontFamily']); ?>"
             style="width: 100%; 
                    text-align: center; 
                    padding: 30px 0; 
                    margin-bottom: <?php echo intval($this->settings['marginBottom']); ?>px;">

            <h1 style="
                font-size: <?php echo floatval($this->settings['fontSize']); ?>em;
                font-weight: bold;
                font-family: <?php echo esc($this->settings['fontFamily']); ?>;
                color: <?php echo esc($this->settings['textColor']); ?>;
                margin-bottom: 5px;
            ">
                <?php echo esc($this->settings['title']); ?>
            </h1>

            <div class="gold-divider" 
                 style="
                    width: 60%; 
                    height: 4px; 
                    background-color: #ddb34d; 
                    margin: 0 auto;
                    border-radius: 2px;
                 ">
            </div>

        </div>
        
        <?php 
        return ob_get_clean();
    }

    public function renderPreview() {
        return '<button class="module-selector-btn" data-module="PageTitle">' 
             . esc($this->settings['buttonName']) . 
             '</button>';
    }
}
?>
