<?php
ini_set('display_errors', 1);
error_reporting(E_ALL);

if (!function_exists('esc')) {
    function esc($string) {
        return htmlspecialchars($string, ENT_QUOTES, 'UTF-8');
    }
}

class ParagraphInput {
    public $settings;
    private $instanceId;

    public function __construct($instanceId = '', $settings = []) {
        $this->instanceId = $instanceId ?: uniqid('paragraphInput_');
        $defaultSettings = [
            'buttonName'   => 'Paragraph Input',
            'headingText'  => 'As a final exercise, please write out the insights and conclusions you reached through this process.',
            'userContent'  => '',
            'editorHeight' => '500',
        ];
        $this->settings = array_merge($defaultSettings, $settings);
    }

    public function render() {
        ob_start(); ?>
        <div class="module-preview paragraph-input-module"
             data-module="ParagraphInput"
             data-module-id="<?php echo esc($this->instanceId); ?>">

            <style>
                .paragraph-input-container {
                    max-width: 800px;
                    margin: 20px auto;
                    font-family: Arial, sans-serif;
                    color: #333;
                    text-align: center;
                }
                .paragraph-input-container h2 {
                    font-size: 20px;
                    font-weight: normal;
                    margin-bottom: 16px;
                }
                .paragraph-editor {
                    margin: 20px 0;
                    border: 1px solid #ccc;
                    border-radius: 6px;
                    overflow: hidden;
                    background: #fff;
                }
                .paragraph-editor textarea {
                    width: 100%;
                    min-height: <?php echo intval($this->settings['editorHeight']); ?>px;
                    box-sizing: border-box;
                }
            </style>

            <div class="paragraph-input-container">
                <h2 class="paragraph-heading"><?php echo esc($this->settings['headingText']); ?></h2>
                <div class="paragraph-editor">
                    <textarea><?php echo esc($this->settings['userContent']); ?></textarea>
                </div>
            </div>
        </div>
        <?php return ob_get_clean();
    }

    public function renderPreview() {
        return '<button class="module-selector-btn" data-module="ParagraphInput">'
             . esc($this->settings['buttonName']) . '</button>';
    }

    public function renderSettings() {
        ob_start(); ?>
        <div id="paragraphInputSettings_<?php echo esc($this->instanceId); ?>" class="module-settings" style="padding: 10px;">
            <h3 style="color: #164986;">Settings<br><small>Paragraph Input</small></h3>

            <label>Heading Text:</label>
            <input type="text" class="paragraph-setting-input"
                   data-setting="headingText"
                   data-instance="<?php echo esc($this->instanceId); ?>"
                   value="<?php echo esc($this->settings['headingText']); ?>"
                   style="width: 100%; margin-bottom: 10px;" />

            <label>Editor Height (px):</label>
            <input type="number" class="paragraph-setting-input"
                   data-setting="editorHeight"
                   data-instance="<?php echo esc($this->instanceId); ?>"
                   value="<?php echo esc($this->settings['editorHeight']); ?>"
                   style="width: 100px;" />
        </div>

        <script>
        (function () {
            const headingInput = document.querySelector('input[data-setting="headingText"][data-instance="<?php echo esc($this->instanceId); ?>"]');
            const heightInput = document.querySelector('input[data-setting="editorHeight"][data-instance="<?php echo esc($this->instanceId); ?>"]');

            if (!headingInput || !heightInput) {
                console.warn("⚠️ Could not find inputs for ParagraphInput <?php echo esc($this->instanceId); ?>");
                return;
            }

            // Heading Text Input Events
            headingInput.addEventListener("focus", () => {
                console.log("🟡 Heading Input Focused");
            });

            headingInput.addEventListener("input", () => {
                const newValue = headingInput.value;
                console.log("🔵 Heading Input Changed:", newValue);

                const instanceId = headingInput.dataset.instance;
                const currentSettings = getModuleSettings(instanceId);
                currentSettings['headingText'] = newValue;
                updateModuleSettings(instanceId, currentSettings);
            });

            headingInput.addEventListener("blur", () => {
                const newValue = headingInput.value;
                console.log("🔴 Heading Input Blurred. Final Value:", newValue);

                const instanceId = headingInput.dataset.instance;
                const currentSettings = getModuleSettings(instanceId);
                currentSettings['headingText'] = newValue;
                updateModuleSettings(instanceId, currentSettings);
            });

            // Editor Height Input Events
            heightInput.addEventListener("input", () => {
                const newValue = heightInput.value;
                console.log("🟢 Editor Height Changed:", newValue);

                const instanceId = heightInput.dataset.instance;
                const currentSettings = getModuleSettings(instanceId);
                currentSettings['editorHeight'] = newValue;
                updateModuleSettings(instanceId, currentSettings);
            });

        })();
        </script>
        <?php
        return ob_get_clean();
    }
}
?>
