<?php

class ParagraphTextAndScripture {
  public function renderPreview($settings = []) {
    $paragraph = $settings['paragraphText'] ?? 'Your main paragraph text here...';
    $scripture = $settings['referenceText'] ?? '';

    // Padding
    $pt = intval($settings['paddingTop'] ?? 16);
    $pr = intval($settings['paddingRight'] ?? 16);
    $pb = intval($settings['paddingBottom'] ?? 16);
    $pl = intval($settings['paddingLeft'] ?? 16);

    // Layout
    $width = $settings['containerWidth'] ?? '100%';
    $align = $settings['textAlign'] ?? 'left';
    $preset = $settings['stylePreset'] ?? 'standard';

    // Set Tailwind classes based on style preset
    if ($preset === 'scripture') {
      $paragraphClasses = 'text-blue-800 italic text-center text-[20px] font-[Open_Sans]';
      $referenceClasses = 'text-blue-800 font-semibold text-center mt-2 text-[20px] font-[Open_Sans]';
    } else {
      $paragraphClasses = 'text-[#5D5D5D] text-left text-[20px] font-normal font-[Open_Sans]';
      $referenceClasses = 'text-[#5D5D5D] font-normal text-left mt-2 text-[20px] font-[Open_Sans]';
    }

    $style = "padding: {$pt}px {$pr}px {$pb}px {$pl}px; width: {$width}; margin: 20px auto;";

    ob_start(); ?>
    <div class="border-2 border-dotted border-gray-400 rounded-lg bg-white" style="<?= $style ?>">
      <div class="<?= $paragraphClasses ?>"><?= nl2br(htmlspecialchars($paragraph)) ?></div>
      <?php if (!empty($scripture)): ?>
        <div class="<?= $referenceClasses ?>">— <?= htmlspecialchars($scripture) ?></div>
      <?php endif; ?>
    </div>
    <?php return ob_get_clean();
  }

  public function renderSettings($settings = []) {
    $paragraph = $settings['paragraphText'] ?? '';
    $scripture = $settings['referenceText'] ?? '';

    $paddingTop = intval($settings['paddingTop'] ?? 16);
    $paddingRight = intval($settings['paddingRight'] ?? 16);
    $paddingBottom = intval($settings['paddingBottom'] ?? 16);
    $paddingLeft = intval($settings['paddingLeft'] ?? 16);

    $containerWidth = $settings['containerWidth'] ?? '100%';
    $textAlign = $settings['textAlign'] ?? 'left';
    $stylePreset = $settings['stylePreset'] ?? '';

    ob_start(); ?>

    <div class="mb-4">
      <label class="block font-bold">Style Preset:</label>
      <select data-style-preset class="w-full p-2 border rounded">
        <option value="">Choose a preset...</option>
        <option value="standard" <?= $stylePreset === 'standard' ? 'selected' : '' ?>>Standard Paragraph</option>
        <option value="scripture" <?= $stylePreset === 'scripture' ? 'selected' : '' ?>>Scripture</option>
      </select>
    </div>

    <script>
    setTimeout(() => {
      const presetDropdown = document.querySelector('[data-style-preset]');
      if (presetDropdown) {
        presetDropdown.addEventListener('change', () => {
          const value = presetDropdown.value;
          const currentSettings = moduleInstances[currentModuleId].settings || {};
          const newSettings = { ...currentSettings, stylePreset: value };
          updateModuleSettings(currentModuleId, newSettings);
        });
      }

      document.querySelectorAll('.padding-control').forEach(row => {
        const range = row.querySelector('input[type=range]');
        const number = row.querySelector('input[type=number]');
        const setting = range.dataset.setting;

        // Sync slider → number
        range.addEventListener('input', () => {
          number.value = range.value;
          updateModuleSettings(currentModuleId, { [setting]: range.value });
        });

        // Sync number → slider
        number.addEventListener('input', () => {
          range.value = number.value;
          updateModuleSettings(currentModuleId, { [setting]: number.value });
        });
      });
    }, 50);
    </script>

    <div class="mb-4">
      <label class="block font-bold">Paragraph Text:</label>
      <textarea data-setting="paragraphText" rows="5" class="w-full p-2 border rounded"><?= htmlspecialchars($paragraph) ?></textarea>
    </div>

    <div class="mb-4">
      <label class="block font-bold">Scripture Reference:</label>
      <input type="text" data-setting="referenceText" class="w-full p-2 border rounded" value="<?= htmlspecialchars($scripture) ?>">
    </div>

    <hr class="my-4">

    <div class="mb-4">
      <label class="block font-bold mb-2">Padding (px):</label>
      <?php foreach (['Top', 'Right', 'Bottom', 'Left'] as $side):
        $key = 'padding' . $side;
        $val = intval($settings[$key] ?? 16);
      ?>
        <div class="padding-control" style="display: flex; align-items: center; margin-bottom: 6px;">
          <label style="width: 50px; text-align: right; font-size: 14px;"><?= $side ?>:</label>
          <input 
            type="range" min="0" max="100" value="<?= $val ?>" 
            data-setting="<?= $key ?>" 
            style="flex: 1; height: 4px; margin: 0 10px;"
          >
          <input 
            type="number" min="0" max="100" value="<?= $val ?>" 
            data-setting="<?= $key ?>" 
            style="width: 50px; padding: 4px; text-align: center; font-size: 13px;"
          >
          <span style="font-size: 12px; color: #666; margin-left: 4px;">px</span>
        </div>
      <?php endforeach; ?>
    </div>

    <div class="mt-4 mb-4">
      <label class="block font-bold">Container Width:</label>
      <select data-setting="containerWidth" class="w-full p-2 border rounded">
        <?php foreach (['100%', '90%', '80%', '70%', '60%', '50%', '40%'] as $w): ?>
          <option value="<?= $w ?>" <?= $containerWidth === $w ? 'selected' : '' ?>><?= $w ?></option>
        <?php endforeach; ?>
      </select>
    </div>

    <div class="mb-4">
      <label class="block font-bold">Text Alignment:</label>
      <select data-setting="textAlign" class="w-full p-2 border rounded">
        <?php foreach (['left', 'center', 'right', 'justify'] as $opt): ?>
          <option value="<?= $opt ?>" <?= $textAlign === $opt ? 'selected' : '' ?>><?= ucfirst($opt) ?></option>
        <?php endforeach; ?>
      </select>
    </div>

    <?php return ob_get_clean();
  }

  public function mergeSettings($current, $new) {
    return array_merge($current, $new);
  }
}
