<?php
// modules/ScriptureModule.php

ini_set('display_errors', 1);
error_reporting(E_ALL);

if (!function_exists('esc')) {
    function esc($string) {
        return htmlspecialchars($string, ENT_QUOTES, 'UTF-8');
    }
}

class ScriptureModule {
    public $settings;
    private $instanceId;

    public function __construct($instanceId = '', $settings = []) {
        $this->instanceId = $instanceId ?: uniqid('scripture_');
        $this->settings = array_merge([
            'buttonName'    => 'Scripture',
            'buttonPosition'  => 4,
            'scriptureText' => '“For if you forgive men their trespasses, your heavenly Father will also forgive you.”',
            'referenceText' => 'Matthew 6:14',
            'fontSize'      => '20px',
            'textAlign'     => 'center',
            'color'         => '#005484'
        ], $settings);
    }

    public function render() {
        ob_start(); ?>
        <div class="module-preview scripture-module"
             data-module="ScriptureModule"
             data-module-id="<?php echo esc($this->instanceId); ?>"
             style="text-align: <?php echo esc($this->settings['textAlign']); ?>;
                    font-family: 'Open Sans', sans-serif;
                    font-size: <?php echo esc($this->settings['fontSize']); ?>;
                    color: <?php echo esc($this->settings['color']); ?>;">

            <!-- Scripture Text -->
            <p class="scripture-text" style="font-style: italic; margin-bottom: 10px;">
                <?php echo esc($this->settings['scriptureText']); ?>
            </p>

            <!-- Reference -->
            <p class="reference-text" style="font-weight: 600;">
                <?php echo esc($this->settings['referenceText']); ?>
            </p>
        </div>
        <?php return ob_get_clean();
    }

    public function renderPreview() {
        return '<button class="module-selector-btn" data-module="ScriptureModule">' 
             . esc($this->settings['buttonName']) . 
             '</button>';
    }

    public function renderSettings() {
        ob_start(); ?>
        <div class="module-settings" id="scriptureSettings_<?php echo esc($this->instanceId); ?>">
            <h3 style="color: #164986;">Settings<br><small>Scripture Module</small></h3>

            <label>Scripture Text:</label>
            <textarea data-setting="scriptureText" data-instance="<?php echo esc($this->instanceId); ?>" class="scripture-setting-input" style="width: 100%; margin-bottom: 10px;"><?php echo esc($this->settings['scriptureText']); ?></textarea>

            <label>Reference Text:</label>
            <input type="text" data-setting="referenceText" data-instance="<?php echo esc($this->instanceId); ?>" class="scripture-setting-input" style="width: 100%; margin-bottom: 10px;" value="<?php echo esc($this->settings['referenceText']); ?>">

            <label>Font Size:</label>
            <input type="text" data-setting="fontSize" data-instance="<?php echo esc($this->instanceId); ?>" class="scripture-setting-input" style="width: 100%; margin-bottom: 10px;" value="<?php echo esc($this->settings['fontSize']); ?>">

            <label>Text Align:</label>
            <select data-setting="textAlign" data-instance="<?php echo esc($this->instanceId); ?>" class="scripture-setting-input" style="width: 100%; margin-bottom: 10px;">
                <option value="left" <?php if ($this->settings['textAlign'] === 'left') echo 'selected'; ?>>Left</option>
                <option value="center" <?php if ($this->settings['textAlign'] === 'center') echo 'selected'; ?>>Center</option>
                <option value="right" <?php if ($this->settings['textAlign'] === 'right') echo 'selected'; ?>>Right</option>
            </select>

            <label>Text Color:</label>
            <input type="color" data-setting="color" data-instance="<?php echo esc($this->instanceId); ?>" class="scripture-setting-input" style="width: 100px;" value="<?php echo esc($this->settings['color']); ?>">
        </div>

        <script>
        document.querySelectorAll('.scripture-setting-input').forEach(input => {
            input.addEventListener('input', () => {
                const instanceId = input.dataset.instance;
                const setting = input.dataset.setting;
                const newValue = input.value;

                console.log("✏️ [Scripture Input] Setting Changed", { instanceId, setting, newValue });

                const currentSettings = getModuleSettings(instanceId);
                currentSettings[setting] = newValue;
                updateModuleSettings(instanceId, currentSettings);
            });
        });
        </script>
        <?php return ob_get_clean();
    }
}
?>
