<?php
// modules/TwoColumnInput.php

ini_set('display_errors', 1);
error_reporting(E_ALL);

if (!function_exists('esc')) {
    function esc($string) {
        return htmlspecialchars($string, ENT_QUOTES, 'UTF-8');
    }
}

class TwoColumnInput {
    public $settings;
    private $instanceId;

    public function __construct($instanceId = '', $settings = []) {
        // Generate a unique ID if none is provided
        $this->instanceId = $instanceId ?: uniqid('twoColumnInput_');

        // Default settings merged with any that are passed in
        $this->settings = array_merge([
            'buttonName'   => 'Two Column Input',
            'buttonPosition'  => 6,
            'leftTitle'    => 'The people that wounded me:',
            'rightTitle'   => 'The painful experiences:',
            // Text fields for the left column
            'leftField1'   => '',
            'leftField2'   => '',
            'leftField3'   => '',
            // Text fields for the right column
            'rightField1'  => '',
            'rightField2'  => '',
            'rightField3'  => '',
        ], $settings);
    }

    /**
     * Renders two columns (each with a heading and 3 inputs) and
     * three horizontal bridging lines that align approximately
     * with each row of inputs.
     */
    public function render() {
        ob_start(); ?>
        
        <div class="module-preview two-column-input-module"
             data-module="TwoColumnInput"
             data-module-id="<?php echo esc($this->instanceId); ?>">

            <!-- Inline CSS that approximates your screenshot's style -->
            <style>
                .outer-container {
                    /* Center this layout and give it a fixed width for consistent alignment */
                    width: 800px; /* Adjust as desired */
                    margin: 0 auto;
                    
                    /* We use position: relative to place bridging lines absolutely */
                    position: relative;
                    
                    display: flex;
                    justify-content: space-between;
                    align-items: flex-start;
                    gap: 40px; /* Space between the two columns */
                    padding: 20px 0; /* Top/bottom spacing */
                }

                /* Each column is a rounded box with a heading and 3 input rows */
                .column-box {
                    background: #F7F9FA;
                    border: 1px solid #ccc;
                    border-radius: 8px;
                    width: 320px; /* Adjust as needed */
                    padding: 20px;
                    box-sizing: border-box;
                }
                .column-box h3 {
                    margin-top: 0;
                    margin-bottom: 20px;
                    font-size: 16px;
                    text-align: center;
                }
                .input-row {
                    margin-bottom: 16px;
                }
                .input-row input {
                    width: 100%;
                    padding: 8px;
                    border: 1px solid #ccc;
                    border-radius: 4px;
                    background: #fff;
                    font-size: 14px;
                }
                .input-row input:focus {
                    outline: none;
                    border-color: #66afe9;
                }

                /* 
                   3 horizontal bridging lines, placed absolutely.
                   The top offsets assume:
                     - ~40px for heading space
                     - ~(some margin) + 1st input row
                     - Then subsequent inputs at +60px increments (approx)
                   Adjust these values if your text or headings differ in size.
                */
                .bridge-line {
                    position: absolute;
                    left: calc(50% - 30px);  /* ~center minus half the line width */
                    width: 60px;             /* horizontal line length */
                    height: 2px;
                    background: #ccc;
                }
                .bridge-line.line1 {
                    top: 90px;  /* approx alignment for the 1st row of inputs */
                }
                .bridge-line.line2 {
                    top: 150px; /* 2nd row */
                }
                .bridge-line.line3 {
                    top: 210px; /* 3rd row */
                }

                /*
                  If you want to better align them, you can tweak the 'top' values
                  or the column-box's spacing. Another approach is to fix the
                  column-box's height so the rows are at consistent offsets.
                */
            </style>

            <div class="outer-container">
                <!-- Left Column -->
                <div class="column-box left-column">
                    <h3><?php echo esc($this->settings['leftTitle']); ?></h3>
                    <div class="input-row">
                        <input type="text" value="<?php echo esc($this->settings['leftField1']); ?>" readonly>
                    </div>
                    <div class="input-row">
                        <input type="text" value="<?php echo esc($this->settings['leftField2']); ?>" readonly>
                    </div>
                    <div class="input-row">
                        <input type="text" value="<?php echo esc($this->settings['leftField3']); ?>" readonly>
                    </div>
                </div>

                <!-- Right Column -->
                <div class="column-box right-column">
                    <h3><?php echo esc($this->settings['rightTitle']); ?></h3>
                    <div class="input-row">
                        <input type="text" value="<?php echo esc($this->settings['rightField1']); ?>" readonly>
                    </div>
                    <div class="input-row">
                        <input type="text" value="<?php echo esc($this->settings['rightField2']); ?>" readonly>
                    </div>
                    <div class="input-row">
                        <input type="text" value="<?php echo esc($this->settings['rightField3']); ?>" readonly>
                    </div>
                </div>

                <!-- 3 bridging lines to approximate alignment with each row -->
                <div class="bridge-line line1"></div>
                <div class="bridge-line line2"></div>
                <div class="bridge-line line3"></div>
            </div>
        </div>
        
        <?php
        return ob_get_clean();
    }

    /**
     * Renders the sidebar button for module selection.
     */
    public function renderPreview() {
        return '<button class="module-selector-btn" data-module="TwoColumnInput">'
             . esc($this->settings['buttonName'])
             . '</button>';
    }

    /**
     * Renders the settings panel for this module.
     */
    public function renderSettings() {
        ob_start(); ?>
        
        <div class="form-group">
            <label for="leftTitle">Left Column Title:</label>
            <input type="text" id="leftTitle" data-update="leftTitle" 
                   value="<?php echo esc($this->settings['leftTitle']); ?>">
        </div>

        <div class="form-group">
            <label for="leftField1">Left Field 1:</label>
            <input type="text" id="leftField1" data-update="leftField1"
                   value="<?php echo esc($this->settings['leftField1']); ?>">
        </div>
        <div class="form-group">
            <label for="leftField2">Left Field 2:</label>
            <input type="text" id="leftField2" data-update="leftField2"
                   value="<?php echo esc($this->settings['leftField2']); ?>">
        </div>
        <div class="form-group">
            <label for="leftField3">Left Field 3:</label>
            <input type="text" id="leftField3" data-update="leftField3"
                   value="<?php echo esc($this->settings['leftField3']); ?>">
        </div>

        <hr>

        <div class="form-group">
            <label for="rightTitle">Right Column Title:</label>
            <input type="text" id="rightTitle" data-update="rightTitle"
                   value="<?php echo esc($this->settings['rightTitle']); ?>">
        </div>

        <div class="form-group">
            <label for="rightField1">Right Field 1:</label>
            <input type="text" id="rightField1" data-update="rightField1"
                   value="<?php echo esc($this->settings['rightField1']); ?>">
        </div>
        <div class="form-group">
            <label for="rightField2">Right Field 2:</label>
            <input type="text" id="rightField2" data-update="rightField2"
                   value="<?php echo esc($this->settings['rightField2']); ?>">
        </div>
        <div class="form-group">
            <label for="rightField3">Right Field 3:</label>
            <input type="text" id="rightField3" data-update="rightField3"
                   value="<?php echo esc($this->settings['rightField3']); ?>">
        </div>

        <?php
        return ob_get_clean();
    }
}
