<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8" />
  <meta name="viewport" content="width=device-width, initial-scale=1.0" />
  <title>Form Builder</title>
  <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet" />
</head>
<body class="bg-gray-100 h-screen">
  <div class="w-full h-full p-4 flex flex-col">
    <h1 class="text-2xl font-bold mb-4 text-center">Form Builder</h1>
    <div class="flex h-full">
      <!-- LEFT SIDEBAR: Add Elements (Fixed Width) -->
      <div class="bg-white p-4 shadow-md" style="width: 250px;">
        <h2 class="font-semibold mb-2">Add Elements</h2>
        <button id="addTitlePage" class="block w-full mb-2 bg-yellow-500 text-white py-2 px-4 rounded">Title Page</button>
        <button id="addText" class="block w-full mb-2 bg-blue-500 text-white py-2 px-4 rounded">Text Field</button>
        <button id="addDropdown" class="block w-full mb-2 bg-green-500 text-white py-2 px-4 rounded">Dropdown</button>
        <button id="addRadio" class="block w-full mb-2 bg-purple-500 text-white py-2 px-4 rounded">Radio Group</button>
        <button id="addCheckbox" class="block w-full mb-2 bg-red-500 text-white py-2 px-4 rounded">Checkbox</button>
        <button id="addPage" class="block w-full mb-2 bg-indigo-500 text-white py-2 px-4 rounded">Add Page</button>
      </div>

      <!-- CENTER: Form Preview (Flexible Width) -->
      <div id="formPreview" class="flex-1 mx-4 bg-white p-4 shadow-md min-h-[300px] overflow-auto">
        <h2 class="font-semibold mb-2 form-preview-title">Form Preview</h2>
      </div>

      <!-- RIGHT SIDEBAR: Edit Element -->
      <div id="rightSidebar" class="w-1/4 bg-white p-4 shadow-md">
        <h2 class="font-semibold mb-2">Edit Element</h2>
        <div id="sidebarInstructions" class="mb-4 text-sm text-gray-600">
          Select an element in the preview area to edit its properties.
        </div>

        <!-- Default Editor (for non-title elements) -->
        <div id="defaultEditor">
          <label class="block text-sm mt-2">Label</label>
          <input type="text" id="elementLabel" class="w-full p-2 border rounded" />
          <label class="block text-sm mt-2">Tooltip</label>
          <input type="text" id="elementTooltip" class="w-full p-2 border rounded" />
          <label class="block text-sm mt-2">Placeholder</label>
          <input type="text" id="elementPlaceholder" class="w-full p-2 border rounded" />

          <!-- Margin & Padding Controls -->
          <h3 class="font-semibold text-sm mt-4">Margins (px)</h3>
          <div class="grid grid-cols-2 gap-2">
            <input type="number" id="marginTop" class="w-full p-2 border rounded" placeholder="Top" />
            <input type="number" id="marginRight" class="w-full p-2 border rounded" placeholder="Right" />
            <input type="number" id="marginBottom" class="w-full p-2 border rounded" placeholder="Bottom" />
            <input type="number" id="marginLeft" class="w-full p-2 border rounded" placeholder="Left" />
          </div>

          <h3 class="font-semibold text-sm mt-4">Padding (px)</h3>
          <div class="grid grid-cols-2 gap-2">
            <input type="number" id="paddingTop" class="w-full p-2 border rounded" placeholder="Top" />
            <input type="number" id="paddingRight" class="w-full p-2 border rounded" placeholder="Right" />
            <input type="number" id="paddingBottom" class="w-full p-2 border rounded" placeholder="Bottom" />
            <input type="number" id="paddingLeft" class="w-full p-2 border rounded" placeholder="Left" />
          </div>

          <!-- Options for Dropdown, Radio, Checkbox -->
          <h3 class="font-semibold text-sm mt-4">Options</h3>
          <div id="elementOptionsContainer"></div>
          <button id="addOptionButton" class="bg-blue-500 text-white py-1 px-2 rounded text-sm mt-2">+</button>
          <div class="mt-2 flex items-center">
            <input type="checkbox" id="addOptionValue" class="mr-2" />
            <label class="text-sm">Add Value Column</label>
          </div>
        </div>

        <!-- Title Page Editor (for Title Pages) -->
        <div id="titleEditor" style="display: none;">
          <h3 class="font-semibold text-sm mt-4">Title Page Settings</h3>
          <label class="block text-sm mt-2">Title</label>
          <input type="text" id="titleTextEditor" class="w-full p-2 border rounded" />
          <label class="block text-sm mt-2">Subtitle</label>
          <input type="text" id="titleSubtitle" class="w-full p-2 border rounded" />
          <label class="block text-sm mt-2">Author</label>
          <input type="text" id="titleAuthor" class="w-full p-2 border rounded" />
        </div>

        <hr class="my-4" />
        <!-- Move / Delete Controls -->
        <div class="flex gap-2">
          <button id="moveUp" class="bg-blue-500 text-white py-1 px-2 rounded">Move Up</button>
          <button id="moveDown" class="bg-blue-500 text-white py-1 px-2 rounded">Move Down</button>
          <button id="deleteElement" class="bg-red-500 text-white py-1 px-2 rounded">Delete</button>
        </div>
      </div>
    </div>
  </div>
  <script src="js/formBuilder.js?v=<?= time(); ?>"></script>
</body>
</html>
