// module-settings-v2.js

function bindSettingsPanelV2(moduleId, panelSelector = '#settings-panel') {
    const panel = $(panelSelector);

    const debounce = (fn, delay = 300) => {
        let timer;
        return function (...args) {
            clearTimeout(timer);
            timer = setTimeout(() => fn.apply(this, args), delay);
        };
    };

    const updateSettings = debounce(() => {
        const settings = {};
        panel.find('[data-setting]').each(function () {
            const key = $(this).data('setting');
            settings[key] = $(this).val();
        });

        console.log(`[V2] Updating module ${moduleId}`, settings);

        $.post('/app-builder/update_module', {
            moduleId: moduleId,
            settings: settings
        }, function (response) {
            if (response.previewHtml && response.settingsHtml) {
                const preview = $(`[data-module-id="${moduleId}"]`);
                preview.replaceWith(response.previewHtml);

                const newSettings = $(panelSelector);
                newSettings.html(response.settingsHtml);

                bindSettingsPanelV2(moduleId, panelSelector);
            } else {
                console.error(`[V2] Failed to update module:`, response);
            }
        });
    });

    panel.find('[data-setting]').off('input change').on('input change', updateSettings);
}
