// pageBreak.js

/**
 * Updates all survey page break modules with dynamic page numbering.
 * The first page break represents the start of Page 2.
 */
function updatePageBreakNumbers() {
    const pageBreaks = document.querySelectorAll('.survey-page-break');
    let pageNumber = 2; // First page break indicates page 2
    pageBreaks.forEach(pb => {
        const marker = pb.querySelector('.page-break-text');
        if (marker) {
            // Set the text without extra dashes, as the CSS will draw the horizontal lines.
            marker.textContent = "Start of Page " + pageNumber;
            pageNumber++;
        }
    });
}

// Expose the function globally so it can be called from your main JS file.
window.updatePageBreakNumbers = updatePageBreakNumbers;

// Optionally, you can auto-call it on DOMContentLoaded:
document.addEventListener("DOMContentLoaded", updatePageBreakNumbers);
