console.log("✅ FONTS.JS LOADED");

const fonts = [
    "Cinzel",
    "Roboto",
    "Open Sans",
    "Lato",
    "Montserrat",
    "Oswald",
    "Source Sans Pro",
    "Raleway",
    "PT Sans",
    "Merriweather",
    "Ubuntu",
    "Poppins",
    "Noto Sans",
    "Roboto Condensed",
    "Playfair Display",
    "Work Sans",
    "Nunito",
    "Fira Sans",
    "Cabin",
    "Noto Serif"
];

export default {
    render(moduleDOM, settingsPanel, moduleDefaults = {}) {
        const fontWrapper = document.createElement('div');
        fontWrapper.innerHTML = `
            <label>Font Family:</label>
            <select data-update="fontFamily"></select>
        `;

        const select = fontWrapper.querySelector('select');

        // Populate the font dropdown
        fonts.forEach(font => {
            const option = document.createElement('option');
            option.value = font;
            option.textContent = font;
            const defaultClean = moduleDefaults.fontFamily?.replace(/['",]/g, '').trim() || "Cinzel";
            if (font === defaultClean) option.selected = true;
            select.appendChild(option);
        });

        // Apply the default or selected font
        const h1 = moduleDOM.querySelector('h1');
        if (h1) h1.style.fontFamily = moduleDefaults.fontFamily || "Cinzel";

        select.addEventListener('change', () => {
            const selectedFont = select.value;
            if (h1) h1.style.fontFamily = selectedFont;
            moduleDOM.setAttribute('data-font-family', selectedFont);

            // Load the selected Google Font
            const linkId = `dynamic-font-${moduleDOM.getAttribute('data-module-id')}`;
            let linkEl = document.getElementById(linkId);
            if (!linkEl) {
                linkEl = document.createElement("link");
                linkEl.id = linkId;
                linkEl.rel = "stylesheet";
                document.head.appendChild(linkEl);
            }
            const formattedFont = selectedFont.replace(/ /g, "+");
            linkEl.href = `https://fonts.googleapis.com/css2?family=${formattedFont}&display=swap`;
        });

        // Pre-load the default font
        const defaultFont = moduleDefaults.fontFamily?.replace(/['",]/g, '').trim() || "Cinzel";
        const preLoadLink = document.createElement("link");
        preLoadLink.rel = "stylesheet";
        preLoadLink.href = `https://fonts.googleapis.com/css2?family=${defaultFont.replace(/ /g, "+")}&display=swap`;
        document.head.appendChild(preLoadLink);

        settingsPanel.appendChild(fontWrapper);
    }
};
