let moduleInstanceCounter = 0;
const moduleInstances = {};
let currentModuleId = null;

window.addModule = function(type) {
  const instanceId = `module-${moduleInstanceCounter++}`;
  const settings = {};

  moduleInstances[instanceId] = { type, settings };

  fetch('/ws-app-maker/update_module', {
    method: 'POST',
    headers: { 'Content-Type': 'application/json' },
    body: JSON.stringify({ instanceId, moduleName: type, settings })
  })
  .then(res => res.json())
  .then(data => {
    const moduleEl = document.createElement('div');
    moduleEl.className = 'module-block border p-4 bg-white rounded shadow';
    moduleEl.id = instanceId;
    moduleEl.innerHTML = data.preview;
    moduleEl.onclick = () => openSettings(instanceId);
    document.getElementById('builder-canvas').appendChild(moduleEl);

    if (currentModuleId === null) {
      openSettings(instanceId);
    }
  });
};

window.openSettings = function(instanceId) {
  const module = moduleInstances[instanceId];
  currentModuleId = instanceId;

  fetch('/ws-app-maker/update_module', {
    method: 'POST',
    headers: { 'Content-Type': 'application/json' },
    body: JSON.stringify({ instanceId, moduleName: module.type, settings: module.settings })
  })
  .then(res => res.json())
  .then(data => {
    document.getElementById('settings-content').innerHTML = data.settings;
    console.log("✅ settings panel loaded for", instanceId);

    // Attach dynamic listeners for live updates
    setTimeout(() => {
      document.querySelectorAll('[data-setting]').forEach(input => {
        const eventType = input.tagName === 'SELECT' ? 'change' : 'input';
        input.addEventListener(eventType, () => {
          const key = input.dataset.setting;
          const value = input.value;
          console.log("⚡ live update:", key, "→", value);
          updateModuleSettings(currentModuleId, { [key]: value });
        });
      });
    }, 50);
  });
};

window.updateModuleSettings = function(instanceId, updatedSettings) {
  console.log("📡 updateModuleSettings called:", instanceId, updatedSettings);

  const module = moduleInstances[instanceId];
  module.settings = { ...module.settings, ...updatedSettings };

  fetch('/ws-app-maker/update_module', {
    method: 'POST',
    headers: { 'Content-Type': 'application/json' },
    body: JSON.stringify({ instanceId, moduleName: module.type, settings: module.settings })
  })
  .then(res => res.json())
  .then(data => {
    console.log("✅ server responded with preview update");
    document.getElementById(instanceId).innerHTML = data.preview;
  });
};
