console.log("🧩 ws-settings.js loaded");

window.moduleSettings = window.moduleSettings || {};

/**
 * Get saved settings for a module instance
 */
function getModuleSettings(instanceId) {
  return window.moduleSettings[instanceId] || {};
}

/**
 * Update settings for a module and re-render via WS App Maker
 */
function updateModuleSettings(instanceId, newSettings) {
  console.log("🛠️ Updating settings for", instanceId, newSettings);
  window.moduleSettings[instanceId] = newSettings;

  const moduleEl = document.querySelector(`[data-module-id="${instanceId}"]`);
  if (!moduleEl) {
    console.warn("⚠️ Module not found in DOM:", instanceId);
    return;
  }

  const moduleType = moduleEl.getAttribute('data-module');

  console.log("📡 Sending to /ws-app-maker/update_module:", {
    moduleType, instanceId, settings: newSettings
  });

  fetch('/ws-app-maker/update_module', {
    method: 'POST',
    headers: { 'Content-Type': 'application/json' },
    body: JSON.stringify({ moduleType, instanceId, settings: newSettings })
  })
    .then(res => res.json())
    .then(data => {
      if (data.error) {
        console.error("❌ Server error:", data.error);
        return;
      }

      // Replace module preview
      const tempDiv = document.createElement('div');
      tempDiv.innerHTML = data.preview.trim();
      const newModule = tempDiv.firstElementChild;
      if (newModule) {
        moduleEl.replaceWith(newModule);
        newModule.classList.add('selected');
        console.log("✅ Replaced preview for", instanceId);
      }

      // Replace settings panel
      const settingsPanel = document.getElementById('settings-content');
      if (settingsPanel) {
        settingsPanel.innerHTML = data.settings;
        console.log("✅ Replaced settings panel for", instanceId);
        initV2Settings(instanceId); // 🔁 Rebind inputs
      }
    })
    .catch(err => {
      console.error("🚨 AJAX error during update:", err);
    });
}

/**
 * Initialize all input bindings for a specific module (V2)
 */
function initV2Settings(instanceId) {
  console.log(`🔁 initV2Settings called for ${instanceId}`);

  const wrapper = document.querySelector(`#settings-content .module-settings[data-module-id="${instanceId}"]`) ||
                  document.querySelector(`#settings-content .module-settings[id$="${instanceId}"]`);

  if (!wrapper) {
    console.warn("⚠️ Settings wrapper not found for", instanceId);
    return;
  }

  const inputs = wrapper.querySelectorAll('[data-setting]');
  console.log(`🎯 Found ${inputs.length} inputs in settings panel for ${instanceId}`);

  inputs.forEach(input => {
    const setting = input.getAttribute('data-setting');

    input.addEventListener('focus', () => {
      console.log(`👀 Focused on [${setting}]`);
    });

    input.addEventListener('input', () => {
      const newValue = input.value;
      const currentSettings = getModuleSettings(instanceId);
      currentSettings[setting] = newValue;
      console.log(`📝 Input for [${setting}]:`, newValue);
      updateModuleSettings(instanceId, currentSettings);
    });

    input.addEventListener('change', () => {
      console.log(`📤 Change detected for [${setting}]:`, input.value);
    });
  });
}
