document.addEventListener('DOMContentLoaded', function () {
    document.getElementById('saveApp').addEventListener('click', function () {
        const appName = document.getElementById('app-name').value.trim();
        const appSlug = document.getElementById('app-slug').value.trim().replace(/\s+/g, '-').toLowerCase();

        if (!appName || !appSlug) {
            alert("❌ Please enter an application name and slug.");
            return;
        }

        // Get all modules & their settings
        const modules = [];
        document.querySelectorAll('.module-preview').forEach(module => {
            const moduleType = module.getAttribute('data-module');
            const moduleId = module.getAttribute('data-module-id');
            const settings = moduleSettingsMarkup[moduleType] || null;
            
            modules.push({
                type: moduleType,
                id: moduleId,
                settings: settings
            });
        });

        const formData = new FormData();
        formData.append('name', appName);
        formData.append('slug', appSlug);
        formData.append('data', JSON.stringify(modules));

        // 🔵 Debugging: Confirm JavaScript is sending data
        console.log("🔵 Sending Data:", { name: appName, slug: appSlug, data: JSON.stringify(modules) });
        alert("🔵 Data is being sent to the server. Check console for details.");

        fetch('save_app.php', {
            method: 'POST',
            body: formData
        })
        .then(response => {
            console.log("🔵 Raw Response:", response);
            return response.json();
        })
        .then(data => {
            console.log("✅ Server Response:", data);
            alert(`✅ Server Response: ${JSON.stringify(data)}`);

            if (data.success) {
                alert('✅ Application saved! Redirecting...');
                window.location.href = data.url;
            } else {
                alert('❌ Error: ' + data.message);
            }
        })
        .catch(error => {
            console.error("❌ Fetch Error:", error);
            alert("❌ Fetch Error: Check the console for details.");
        });
    });
});
